# This is Python ORM for SQL Databases




#### Helpful command for publish module
* To preparing dist folder
`python .\setup.py sdist bdist_wheel`
* To publish to pypi server
`twine upload --repository-url https://upload.pypi.org/legacy/ dist/*`